==> cost-interface-0.2.8-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/ExclusiveStorePayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import java.io.Serializable;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.ExclusiveStoreRegistVo;

/**
 * 专卖店支持登记
 */
public class ExclusiveStorePayVo implements Serializable {
	
	
	/**对应登记单行项目信息*/
	private ExclusiveStoreRegistVo registVo;

    private Integer id;

    /**
     * 核报单号
     */
    private String payNo;

    /**
     * 行项目号
     */
    private String itemNo;

    /**
     * 核报类型(10租金,20装修,30人员)
     */
    private Integer payType;

    /**
     * 登记单号
     */
    private String registNo;

    /**
     * 登记单行项目号
     */
    private String registItemNo;

    /**
     * 申请单号
     */
    private String applyNo;

    /**
     * 费用类型编码
     */
    private String costTypeId;

    /**
     * 费用类型编码
     */
    private String costTypeName;

    /**
     * 核报金额(分)
     */
    private BigDecimal auditAmount;

    /**
     * 督查意见
     */
    private String auditNotes;

    /**
     * 年月期间
     */
    private String timeRange;

    /**
     * 经销商打款金额(分)
     */
    private BigDecimal dealerPayAmount;

    private String createId;

    /**
     * 
     * 表字段 : exclusive_store_pay.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : exclusive_store_pay.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : exclusive_store_pay.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : exclusive_store_pay.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : exclusive_store_pay.modify_date
     */
    private Date modifyDate;

    private static final long serialVersionUID = 1L;

    /**
     * 获取  字段:exclusive_store_pay.id
     *
     * @return exclusive_store_pay.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:exclusive_store_pay.id
     *
     * @param id the value for exclusive_store_pay.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 核报单号 字段:exclusive_store_pay.pay_no
     *
     * @return exclusive_store_pay.pay_no, 核报单号
     */
    public String getPayNo() {
        return payNo;
    }

    /**
     * 设置 核报单号 字段:exclusive_store_pay.pay_no
     *
     * @param payNo the value for exclusive_store_pay.pay_no, 核报单号
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 获取 行项目号 字段:exclusive_store_pay.item_no
     *
     * @return exclusive_store_pay.item_no, 行项目号
     */
    public String getItemNo() {
        return itemNo;
    }

    /**
     * 设置 行项目号 字段:exclusive_store_pay.item_no
     *
     * @param itemNo the value for exclusive_store_pay.item_no, 行项目号
     */
    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取 核报类型(10租金,20装修,30人员) 字段:exclusive_store_pay.pay_type
     *
     * @return exclusive_store_pay.pay_type, 核报类型(10租金,20装修,30人员)
     */
    public Integer getPayType() {
        return payType;
    }

    /**
     * 设置 核报类型(10租金,20装修,30人员) 字段:exclusive_store_pay.pay_type
     *
     * @param payType the value for exclusive_store_pay.pay_type, 核报类型(10租金,20装修,30人员)
     */
    public void setPayType(Integer payType) {
        this.payType = payType;
    }

    /**
     * 获取 登记单号 字段:exclusive_store_pay.regist_no
     *
     * @return exclusive_store_pay.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:exclusive_store_pay.regist_no
     *
     * @param registNo the value for exclusive_store_pay.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 获取 登记单行项目号 字段:exclusive_store_pay.regist_item_no
     *
     * @return exclusive_store_pay.regist_item_no, 登记单行项目号
     */
    public String getRegistItemNo() {
        return registItemNo;
    }

    /**
     * 设置 登记单行项目号 字段:exclusive_store_pay.regist_item_no
     *
     * @param registItemNo the value for exclusive_store_pay.regist_item_no, 登记单行项目号
     */
    public void setRegistItemNo(String registItemNo) {
        this.registItemNo = registItemNo;
    }

    /**
     * 获取 申请单号 字段:exclusive_store_pay.apply_no
     *
     * @return exclusive_store_pay.apply_no, 申请单号
     */
    public String getApplyNo() {
        return applyNo;
    }

    /**
     * 设置 申请单号 字段:exclusive_store_pay.apply_no
     *
     * @param applyNo the value for exclusive_store_pay.apply_no, 申请单号
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 获取 费用类型编码 字段:exclusive_store_pay.cost_type_id
     *
     * @return exclusive_store_pay.cost_type_id, 费用类型编码
     */
    public String getCostTypeId() {
        return costTypeId;
    }

    /**
     * 设置 费用类型编码 字段:exclusive_store_pay.cost_type_id
     *
     * @param costTypeId the value for exclusive_store_pay.cost_type_id, 费用类型编码
     */
    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    /**
     * 获取 费用类型编码 字段:exclusive_store_pay.cost_type_name
     *
     * @return exclusive_store_pay.cost_type_name, 费用类型编码
     */
    public String getCostTypeName() {
        return costTypeName;
    }

    /**
     * 设置 费用类型编码 字段:exclusive_store_pay.cost_type_name
     *
     * @param costTypeName the value for exclusive_store_pay.cost_type_name, 费用类型编码
     */
    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    /**
     * 获取 核报金额(分) 字段:exclusive_store_pay.audit_amount
     *
     * @return exclusive_store_pay.audit_amount, 核报金额(分)
     */
    public BigDecimal getAuditAmount() {
    	if( this.auditAmount != null) {
            return (this.auditAmount.divide(new BigDecimal(100),2, RoundingMode.HALF_UP));
        }
        return auditAmount;
    }

    /**
     * 设置 核报金额(分) 字段:exclusive_store_pay.audit_amount
     *
     * @param auditAmount the value for exclusive_store_pay.audit_amount, 核报金额(分)
     */
    public void setAuditAmount(BigDecimal auditAmount) {
        this.auditAmount = auditAmount;
    }

    /**
     * 获取 督查意见 字段:exclusive_store_pay.audit_notes
     *
     * @return exclusive_store_pay.audit_notes, 督查意见
     */
    public String getAuditNotes() {
        return auditNotes;
    }

    /**
     * 设置 督查意见 字段:exclusive_store_pay.audit_notes
     *
     * @param auditNotes the value for exclusive_store_pay.audit_notes, 督查意见
     */
    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    /**
     * 获取 年月期间 字段:exclusive_store_pay.time_range
     *
     * @return exclusive_store_pay.time_range, 年月期间
     */
    public String getTimeRange() {
        return timeRange;
    }

    public ExclusiveStoreRegistVo getRegistVo() {
		return registVo;
	}

	public void setRegistVo(ExclusiveStoreRegistVo registVo) {
		this.registVo = registVo;
	}

	/**
     * 设置 年月期间 字段:exclusive_store_pay.time_range
     *
     * @param timeRange the value for exclusive_store_pay.time_range, 年月期间
     */
    public void setTimeRange(String timeRange) {
        this.timeRange = timeRange;
    }

    /**
     * 获取 经销商打款金额(分) 字段:exclusive_store_pay.dealer_pay_amount
     *
     * @return exclusive_store_pay.dealer_pay_amount, 经销商打款金额(分)
     */
    public BigDecimal getDealerPayAmount() {
    	if( this.dealerPayAmount != null) {
            return (this.dealerPayAmount.divide(new BigDecimal(100),2, RoundingMode.HALF_UP));
        }
        return dealerPayAmount;
    }

    /**
     * 设置 经销商打款金额(分) 字段:exclusive_store_pay.dealer_pay_amount
     *
     * @param dealerPayAmount the value for exclusive_store_pay.dealer_pay_amount, 经销商打款金额(分)
     */
    public void setDealerPayAmount(BigDecimal dealerPayAmount) {
        this.dealerPayAmount = dealerPayAmount;
    }

    /**
     * 获取  字段:exclusive_store_pay.create_id
     *
     * @return exclusive_store_pay.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:exclusive_store_pay.create_id
     *
     * @param createId the value for exclusive_store_pay.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:exclusive_store_pay.create_name
     *
     * @return exclusive_store_pay.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:exclusive_store_pay.create_name
     *
     * @param createName the value for exclusive_store_pay.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:exclusive_store_pay.create_date
     *
     * @return exclusive_store_pay.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:exclusive_store_pay.create_date
     *
     * @param createDate the value for exclusive_store_pay.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:exclusive_store_pay.modify_id
     *
     * @return exclusive_store_pay.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:exclusive_store_pay.modify_id
     *
     * @param modifyId the value for exclusive_store_pay.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:exclusive_store_pay.modify_name
     *
     * @return exclusive_store_pay.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:exclusive_store_pay.modify_name
     *
     * @param modifyName the value for exclusive_store_pay.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:exclusive_store_pay.modify_date
     *
     * @return exclusive_store_pay.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }


	/**
     * 设置  字段:exclusive_store_pay.modify_date
     *
     * @param modifyDate the value for exclusive_store_pay.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

}

==> cost-interface-0.3.3-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/ExclusiveStorePayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import java.io.Serializable;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.ExclusiveStoreRegistVo;

/**
 * 专卖店支持登记
 */
public class ExclusiveStorePayVo implements Serializable {
	
	
	/**对应登记单行项目信息*/
	private ExclusiveStoreRegistVo registVo;

    private Integer id;

    /**
     * 核报单号
     */
    private String payNo;

    /**
     * 行项目号
     */
    private String itemNo;

    /**
     * 核报类型(10租金,20装修,30人员)
     */
    private Integer payType;

    /**
     * 登记单号
     */
    private String registNo;

    /**
     * 登记单行项目号
     */
    private String registItemNo;

    /**
     * 申请单号
     */
    private String applyNo;

    /**
     * 费用类型编码
     */
    private String costTypeId;

    /**
     * 费用类型编码
     */
    private String costTypeName;

    /**
     * 核报金额(分)
     */
    private BigDecimal payAmount;

    /**
     * 督查意见
     */
    private String auditNotes;

    /**
     * 年月期间
     */
    private String timeRange;

    /**
     * 经销商打款金额(分)
     */
    private BigDecimal dealerPayAmount;

    private String createId;

    /**
     * 
     * 表字段 : exclusive_store_pay.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : exclusive_store_pay.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : exclusive_store_pay.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : exclusive_store_pay.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : exclusive_store_pay.modify_date
     */
    private Date modifyDate;

    private static final long serialVersionUID = 1L;

    /**
     * 获取  字段:exclusive_store_pay.id
     *
     * @return exclusive_store_pay.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:exclusive_store_pay.id
     *
     * @param id the value for exclusive_store_pay.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 核报单号 字段:exclusive_store_pay.pay_no
     *
     * @return exclusive_store_pay.pay_no, 核报单号
     */
    public String getPayNo() {
        return payNo;
    }

    /**
     * 设置 核报单号 字段:exclusive_store_pay.pay_no
     *
     * @param payNo the value for exclusive_store_pay.pay_no, 核报单号
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 获取 行项目号 字段:exclusive_store_pay.item_no
     *
     * @return exclusive_store_pay.item_no, 行项目号
     */
    public String getItemNo() {
        return itemNo;
    }

    /**
     * 设置 行项目号 字段:exclusive_store_pay.item_no
     *
     * @param itemNo the value for exclusive_store_pay.item_no, 行项目号
     */
    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取 核报类型(10租金,20装修,30人员) 字段:exclusive_store_pay.pay_type
     *
     * @return exclusive_store_pay.pay_type, 核报类型(10租金,20装修,30人员)
     */
    public Integer getPayType() {
        return payType;
    }

    /**
     * 设置 核报类型(10租金,20装修,30人员) 字段:exclusive_store_pay.pay_type
     *
     * @param payType the value for exclusive_store_pay.pay_type, 核报类型(10租金,20装修,30人员)
     */
    public void setPayType(Integer payType) {
        this.payType = payType;
    }

    /**
     * 获取 登记单号 字段:exclusive_store_pay.regist_no
     *
     * @return exclusive_store_pay.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:exclusive_store_pay.regist_no
     *
     * @param registNo the value for exclusive_store_pay.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 获取 登记单行项目号 字段:exclusive_store_pay.regist_item_no
     *
     * @return exclusive_store_pay.regist_item_no, 登记单行项目号
     */
    public String getRegistItemNo() {
        return registItemNo;
    }

    /**
     * 设置 登记单行项目号 字段:exclusive_store_pay.regist_item_no
     *
     * @param registItemNo the value for exclusive_store_pay.regist_item_no, 登记单行项目号
     */
    public void setRegistItemNo(String registItemNo) {
        this.registItemNo = registItemNo;
    }

    /**
     * 获取 申请单号 字段:exclusive_store_pay.apply_no
     *
     * @return exclusive_store_pay.apply_no, 申请单号
     */
    public String getApplyNo() {
        return applyNo;
    }

    /**
     * 设置 申请单号 字段:exclusive_store_pay.apply_no
     *
     * @param applyNo the value for exclusive_store_pay.apply_no, 申请单号
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 获取 费用类型编码 字段:exclusive_store_pay.cost_type_id
     *
     * @return exclusive_store_pay.cost_type_id, 费用类型编码
     */
    public String getCostTypeId() {
        return costTypeId;
    }

    /**
     * 设置 费用类型编码 字段:exclusive_store_pay.cost_type_id
     *
     * @param costTypeId the value for exclusive_store_pay.cost_type_id, 费用类型编码
     */
    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    /**
     * 获取 费用类型编码 字段:exclusive_store_pay.cost_type_name
     *
     * @return exclusive_store_pay.cost_type_name, 费用类型编码
     */
    public String getCostTypeName() {
        return costTypeName;
    }

    /**
     * 设置 费用类型编码 字段:exclusive_store_pay.cost_type_name
     *
     * @param costTypeName the value for exclusive_store_pay.cost_type_name, 费用类型编码
     */
    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }
    
    

    public BigDecimal getPayAmount() {
		return payAmount;
	}

	public void setPayAmount(BigDecimal payAmount) {
		this.payAmount = payAmount;
	}


    /**
     * 获取 督查意见 字段:exclusive_store_pay.audit_notes
     *
     * @return exclusive_store_pay.audit_notes, 督查意见
     */
    public String getAuditNotes() {
        return auditNotes;
    }

    /**
     * 设置 督查意见 字段:exclusive_store_pay.audit_notes
     *
     * @param auditNotes the value for exclusive_store_pay.audit_notes, 督查意见
     */
    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    /**
     * 获取 年月期间 字段:exclusive_store_pay.time_range
     *
     * @return exclusive_store_pay.time_range, 年月期间
     */
    public String getTimeRange() {
        return timeRange;
    }

    public ExclusiveStoreRegistVo getRegistVo() {
		return registVo;
	}

	public void setRegistVo(ExclusiveStoreRegistVo registVo) {
		this.registVo = registVo;
	}

	/**
     * 设置 年月期间 字段:exclusive_store_pay.time_range
     *
     * @param timeRange the value for exclusive_store_pay.time_range, 年月期间
     */
    public void setTimeRange(String timeRange) {
        this.timeRange = timeRange;
    }

    /**
     * 获取 经销商打款金额(分) 字段:exclusive_store_pay.dealer_pay_amount
     *
     * @return exclusive_store_pay.dealer_pay_amount, 经销商打款金额(分)
     */
    public BigDecimal getDealerPayAmount() {
    	if( this.dealerPayAmount != null) {
            return (this.dealerPayAmount.divide(new BigDecimal(100),2, RoundingMode.HALF_UP));
        }
        return dealerPayAmount;
    }

    /**
     * 设置 经销商打款金额(分) 字段:exclusive_store_pay.dealer_pay_amount
     *
     * @param dealerPayAmount the value for exclusive_store_pay.dealer_pay_amount, 经销商打款金额(分)
     */
    public void setDealerPayAmount(BigDecimal dealerPayAmount) {
        this.dealerPayAmount = dealerPayAmount;
    }

    /**
     * 获取  字段:exclusive_store_pay.create_id
     *
     * @return exclusive_store_pay.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:exclusive_store_pay.create_id
     *
     * @param createId the value for exclusive_store_pay.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:exclusive_store_pay.create_name
     *
     * @return exclusive_store_pay.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:exclusive_store_pay.create_name
     *
     * @param createName the value for exclusive_store_pay.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:exclusive_store_pay.create_date
     *
     * @return exclusive_store_pay.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:exclusive_store_pay.create_date
     *
     * @param createDate the value for exclusive_store_pay.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:exclusive_store_pay.modify_id
     *
     * @return exclusive_store_pay.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:exclusive_store_pay.modify_id
     *
     * @param modifyId the value for exclusive_store_pay.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:exclusive_store_pay.modify_name
     *
     * @return exclusive_store_pay.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:exclusive_store_pay.modify_name
     *
     * @param modifyName the value for exclusive_store_pay.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:exclusive_store_pay.modify_date
     *
     * @return exclusive_store_pay.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }


	/**
     * 设置  字段:exclusive_store_pay.modify_date
     *
     * @param modifyDate the value for exclusive_store_pay.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

}
